require_relative '../helper.rb'

class OutputTest < Test::Unit::TestCase
  def setup
    assert_equal '',  out
    assert_equal '',  err
  end

  test 'wrap_output should trap standard out' do
    std_out = $stdout
    wrap_output {
      puts 'standard out'
    }
    assert_equal std_out, $stdout
    assert_equal "standard out\n", @out.string
  end

  test 'wrap_output should trap standard error' do
    std_err = $stderr
    wrap_output {
      warn 'standard error'
    }
    assert_equal std_err, $stderr
    assert_equal "standard error\n", @err.string
  end

  test 'wrap_output should reset standard out and standard error if the block raises an error' do
    std_out = $stdout
    std_err = $stderr
    assert_raise(RuntimeError) {
      wrap_output {
        raise 'random error'
      }
    }
    assert_equal std_out, $stdout
    assert_equal std_err, $stderr
  end

  test 'out and err should remove the trailing new line' do
    wrap_output {
      puts 'one'
      puts 'two'
      warn 'one'
      warn 'two'
    }
    assert_equal "one\ntwo", out
    assert_equal "one\ntwo", err
  end

  test 'standard out and standard error can be tracked across calls to wrap_output until reset' do
    wrap_output {
      puts 'one out'
      warn 'one err'
    }
    wrap_output {
      puts 'two out'
      warn 'two err'
    }
    assert_equal "one out\ntwo out", out
    assert_equal "one err\ntwo err", err

    reset_io

    wrap_output {
      puts 'three out'
      warn 'three err'
    }
    assert_equal 'three out', out
    assert_equal 'three err', err
  end

  test 'out and err strip all trailing new lines' do
    wrap_output {
      puts 'out'
      puts ''
      puts ''
      warn 'err'
      warn ''
      warn ''
    }
    assert_equal 'out', out
    assert_equal 'err', err
  end

  test 'real_finis should return both standard out and standard error' do
    wrap_output {
      puts 'one'
      warn 'two'
    }
    assert_equal 'one', out
    assert_equal 'two', err
    assert_equal [out, err], real_finis
  end
end
